==> articdata-1.16.3-3d941269.jar: CONTENT_DOCUMENTATION.md <==
### Attributes

|       Data Type        |     Supported?      |
|:----------------------:|:-------------------:|
|      Protocol ID       | :heavy_check_mark:  |
|      Namespace ID      | :heavy_check_mark:  |
|      Mojang Name       | :heavy_check_mark:  |
|    Translation Key     | :heavy_check_mark:  |
|     Default Value      | :heavy_check_mark:  |
| Client Synchronization | :heavy_check_mark:  |
|    Attribute Range     | :heavy_check_mark:  |

### Biomes

|       Data Type        |     Supported?      |
|:----------------------:|:-------------------:|
|      Namespace ID      | :heavy_check_mark:  |
|      Mojang Name       | :heavy_check_mark:  |
|        Humidity        | :heavy_check_mark:  |
|         Scale          | :heavy_check_mark:  |
|         Depth          | :heavy_check_mark:  |
|      Temperature       | :heavy_check_mark:  |
|     Percipitation      | :heavy_check_mark:  |
|        Downfall        | :heavy_check_mark:  |
|       Fog Color        | :heavy_check_mark:  |
|      Water Color       | :heavy_check_mark:  |
|    Water Fog Color     | :heavy_check_mark:  |
|       Sky Color        | :heavy_check_mark:  |
|      Grass Color       | :heavy_check_mark:  |
|  Grass Color Modifier  | :heavy_check_mark:  |
|     Foliage Color      | :heavy_check_mark:  |
| Foliage Color Override | :heavy_check_mark:  |
|        Category        | :heavy_check_mark:  |

### Blocks

|          Data Type           |     Supported?      |
|:----------------------------:|:-------------------:|
|         Protocol ID          | :heavy_check_mark:  |
|         Namespace ID         | :heavy_check_mark:  |
|         Mojang Name          | :heavy_check_mark:  |
|       Translation Key        | :heavy_check_mark:  |
|        Loot Table Key        | :heavy_check_mark:  |
|         Block States         | :heavy_check_mark:  |
|    BlockState Properties     | :heavy_check_mark:  |
|        Block Entities        | :heavy_check_mark:  |
|           Hardness           | :heavy_check_mark:  |
|     Explosion Resistance     | :heavy_check_mark:  |
|           Friction           | :heavy_check_mark:  |
|     Speed & Jump Factor      | :heavy_check_mark:  |
|     Default Block State      | :heavy_check_mark:  |
|      Corresponding Item      | :heavy_check_mark:  |
|   Corresponding Map Color    | :heavy_check_mark:  |
| Solid, Liquid, Blocking etc. | :heavy_check_mark:  |
|     Piston Push Reaction     | :heavy_check_mark:  |
|           Gravity            | :heavy_check_mark:  |
|      Respawn Eligiblity      | :heavy_check_mark:  |
|    Tool Require For Drops    | :heavy_check_mark:  |
|    Large Collision Shape     | :heavy_check_mark:  |
|  Collision Shape Full Block  | :heavy_check_mark:  |
|          Occlusion           | :heavy_check_mark:  |
|            Hitbox            | :heavy_check_mark:  |
|       Collision Hitbox       | :heavy_check_mark:  |
|      Interaction Hitbox      | :heavy_check_mark:  |
|       Occlusion Hitbox       | :heavy_check_mark:  |
|        Visual Hitbox         | :heavy_check_mark:  |
|        Dynamic Shape         | :heavy_check_mark:  |
|         Solid Render         | :heavy_check_mark:  |
|        Light Emission        | :heavy_check_mark:  |
|         Light Block          | :heavy_check_mark:  |
|   Propagates Skylight Down   | :heavy_check_mark:  |
|  Shape for Light Occlusion   | :heavy_check_mark:  |
|           Opacity            | :heavy_check_mark:  |
|     Conditional Opacity      | :heavy_check_mark:  |
|         Render Shape         | :heavy_check_mark:  |
|      Sound Information       | :heavy_check_mark:  |

### Block Entities

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |
|  Block IDs   | :heavy_check_mark:  |

### Block Properties

|    Data Type    |     Supported?      |
|:---------------:|:-------------------:|
|   Mojang Name   | :heavy_check_mark:  |
|       Key       | :heavy_check_mark:  |
| Possible Values | :heavy_check_mark:  |

### Commands

|      Data Type      |     Supported?      |           Description            |
|:-------------------:|:-------------------:|:--------------------------------:|
| Entire Command Tree | :heavy_check_mark:  | See https://wiki.vg/Command_Data |

### Custom Statistics

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |

### Dimension Types

|      Data Type       |     Supported?      |
|:--------------------:|:-------------------:|
|     Namespace ID     | :heavy_check_mark:  |
|      Bed Works       | :heavy_check_mark:  |
|   Coordinate Scale   | :heavy_check_mark:  |
|    Ceiling Height    | :heavy_check_mark:  |
|      Fixed Time      | :heavy_check_mark:  |
|        Raids         | :heavy_check_mark:  |
|      Sky Light       | :heavy_check_mark:  |
|     Piglin Safe      | :heavy_check_mark:  |
|    Logical Height    | :heavy_check_mark:  |
|       Natural        | :heavy_check_mark:  |
|      Ultra Warm      | :heavy_check_mark:  |
| Respawn Anchor Works | :heavy_check_mark:  |

### Dye Colors

|            Data Type             |     Supported?      |
|:--------------------------------:|:-------------------:|
|           Protocol ID            | :heavy_check_mark:  |
|           Mojang Name            | :heavy_check_mark:  |
|      Color (Material Color)      | :heavy_check_mark:  |
|     Firework Color (Decimal)     | :heavy_check_mark:  |
|       Text Color (Decimal)       | :heavy_check_mark:  |
|  TextureDiffuseColor (Decimal)   | :heavy_check_mark:  |
| TextureDiffuseColorBGR (Decimal) | :heavy_check_mark:  |
|       TextureDiffuseColors       | :heavy_check_mark:  |

### Enchantments

|         Data Type         |     Supported?      |
|:-------------------------:|:-------------------:|
|        Protocol ID        | :heavy_check_mark:  |
|       Namespace ID        | :heavy_check_mark:  |
|        Mojang Name        | :heavy_check_mark:  |
|      Translation Key      | :heavy_check_mark:  |
|         Max Level         | :heavy_check_mark:  |
|          Rarity           | :heavy_check_mark:  |
|           Curse           | :heavy_check_mark:  |
|       Discoverable        | :heavy_check_mark:  |
|         Tradeable         | :heavy_check_mark:  |
|       Treasure Only       | :heavy_check_mark:  |
|         Category          | :heavy_check_mark:  |
| Incompatible Enchantments | :heavy_check_mark:  |

### Entities

|        Data Type        |     Supported?      |
|:-----------------------:|:-------------------:|
|       Protocol ID       | :heavy_check_mark:  |
|      Namespace ID       | :heavy_check_mark:  |
|       Mojang Name       | :heavy_check_mark:  |
|     Translation Key     | :heavy_check_mark:  |
|     Loot Table Key      | :heavy_check_mark:  |
| Entity Data Packet Info | :heavy_check_mark:  |
|       Packet Type       | :heavy_check_mark:  |
|      Fire Immunity      | :heavy_check_mark:  |
|         Height          | :heavy_check_mark:  |
|          Width          | :heavy_check_mark:  |
|  Client Tracking Range  | :heavy_check_mark:  |

### Entity Data Serializers

|  Data Type  |     Supported?      |
|:-----------:|:-------------------:|
| Protocol ID | :heavy_check_mark:  |
| Mojang Name | :heavy_check_mark:  |

### Fluids

|         Data Type         |     Supported?      |
|:-------------------------:|:-------------------:|
|        Protocol ID        | :heavy_check_mark:  |
|       Namespace ID        | :heavy_check_mark:  |
|        Mojang Name        | :heavy_check_mark:  |
| Corresponding Bucket Item | :heavy_check_mark:  |

### Fluid Properties

| Data Type | Supported? |
|:---------:|:----------:|


### Map Colors

|    Data Type    |     Supported?      |
|:---------------:|:-------------------:|
|   Protocol ID   | :heavy_check_mark:  |
|   Mojang Name   | :heavy_check_mark:  |
| Color (Decimal) | :heavy_check_mark:  |

### Items

|        Data Type        |     Supported?      |
|:-----------------------:|:-------------------:|
|       Protocol ID       | :heavy_check_mark:  |
|      Namespace ID       | :heavy_check_mark:  |
|       Mojang Name       | :heavy_check_mark:  |
|     Translation Key     | :heavy_check_mark:  |
|        Depletes         | :heavy_check_mark:  |
|     Max Stack Size      | :heavy_check_mark:  |
| Max Damage (Durability) | :heavy_check_mark:  |
|         Edible          | :heavy_check_mark:  |
|     Fire Resistant      | :heavy_check_mark:  |
|   Corresponding Block   | :heavy_check_mark:  |
| Eating & Drinking Sound | :heavy_check_mark:  |
|     Food Properties     | :heavy_check_mark:  |
|    Armor Properties     | :heavy_check_mark:  |
|  Spawn Egg Properties   | :heavy_check_mark:  |
|     Tool Properties     | :heavy_check_mark:  |
|    Bucket Properties    | :heavy_check_mark:  |
|     Dye Properties      | :heavy_check_mark:  |

### Potion Effects

|    Data Type    |     Supported?      |
|:---------------:|:-------------------:|
|   Protocol ID   | :heavy_check_mark:  |
|  Namespace ID   | :heavy_check_mark:  |
|   Mojang Name   | :heavy_check_mark:  |
| Color (Decimal) | :heavy_check_mark:  |
|  Instanteneous  | :heavy_check_mark:  |

### Packets

|    Data Type     |     Supported?      |
|:----------------:|:-------------------:|
|    Packet ID     | :heavy_check_mark:  |
| Packet Classname | :heavy_check_mark:  |
| Packet Direction | :heavy_check_mark:  |
| Connection State | :heavy_check_mark:  |

### Particles

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |

### Potions

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |

### Recipes

|  Data Type  |     Supported?      |
|:-----------:|:-------------------:|
|  Mojang ID  | :heavy_check_mark:  |
| Recipe Type | :heavy_check_mark:  |
|   Layout    | :heavy_check_mark:  |
|   Recipe    | :heavy_check_mark:  |
|   Result    | :heavy_check_mark:  |

### Sounds

|    Data Type    |     Supported?      |
|:---------------:|:-------------------:|
|   Protocol ID   | :heavy_check_mark:  |
|  Namespace ID   | :heavy_check_mark:  |
|   Mojang Name   | :heavy_check_mark:  |
| Translation Key | :heavy_check_mark:  |

### Sound Sources

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
|     Type     | :heavy_check_mark:  |

### Villager Professions

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |
|  Work Sound  | :heavy_check_mark:  |

### Villager Types

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |

==> articdata-1.17.1-3d941269.jar: CONTENT_DOCUMENTATION.md <==
### Attributes

|       Data Type        |     Supported?      |
|:----------------------:|:-------------------:|
|      Protocol ID       | :heavy_check_mark:  |
|      Namespace ID      | :heavy_check_mark:  |
|      Mojang Name       | :heavy_check_mark:  |
|    Translation Key     | :heavy_check_mark:  |
|     Default Value      | :heavy_check_mark:  |
| Client Synchronization | :heavy_check_mark:  |
|    Attribute Range     | :heavy_check_mark:  |

### Biomes

|       Data Type        |     Supported?      |
|:----------------------:|:-------------------:|
|      Protocol ID       | :heavy_check_mark:  |
|      Namespace ID      | :heavy_check_mark:  |
|      Mojang Name       | :heavy_check_mark:  |
|        Humidity        | :heavy_check_mark:  |
|         Scale          | :heavy_check_mark:  |
|         Depth          | :heavy_check_mark:  |
|      Temperature       | :heavy_check_mark:  |
|        Downfall        | :heavy_check_mark:  |
|     Precipitation      | :heavy_check_mark:  |
|      Ambient Loop      | :heavy_check_mark:  |
|      Ambient Mood      | :heavy_check_mark:  |
|    Ambient Particle    | :heavy_check_mark:  |
|   Ambient Additions    | :heavy_check_mark:  |
|    Background Music    | :heavy_check_mark:  |
|       Fog Color        | :heavy_check_mark:  |
|      Water Color       | :heavy_check_mark:  |
|    Water Fog Color     | :heavy_check_mark:  |
|       Sky Color        | :heavy_check_mark:  |
|      Grass Color       | :heavy_check_mark:  |
|  Grass Color Modifier  | :heavy_check_mark:  |
|     Foliage Color      | :heavy_check_mark:  |
| Foliage Color Override | :heavy_check_mark:  |
|        Category        | :heavy_check_mark:  |

### Blocks

|          Data Type           |     Supported?      |
|:----------------------------:|:-------------------:|
|         Protocol ID          | :heavy_check_mark:  |
|         Namespace ID         | :heavy_check_mark:  |
|         Mojang Name          | :heavy_check_mark:  |
|       Translation Key        | :heavy_check_mark:  |
|        Loot Table Key        | :heavy_check_mark:  |
|         Block States         | :heavy_check_mark:  |
|    BlockState Properties     | :heavy_check_mark:  |
|        Block Entities        | :heavy_check_mark:  |
|           Hardness           | :heavy_check_mark:  |
|     Explosion Resistance     | :heavy_check_mark:  |
|           Friction           | :heavy_check_mark:  |
|     Speed & Jump Factor      | :heavy_check_mark:  |
|     Default Block State      | :heavy_check_mark:  |
|      Corresponding Item      | :heavy_check_mark:  |
|   Corresponding Map Color    | :heavy_check_mark:  |
| Solid, Liquid, Blocking etc. | :heavy_check_mark:  |
|     Piston Push Reaction     | :heavy_check_mark:  |
|           Gravity            | :heavy_check_mark:  |
|      Respawn Eligiblity      | :heavy_check_mark:  |
|    Tool Require For Drops    | :heavy_check_mark:  |
|    Large Collision Shape     | :heavy_check_mark:  |
|  Collision Shape Full Block  | :heavy_check_mark:  |
|          Occlusion           | :heavy_check_mark:  |
|            Hitbox            | :heavy_check_mark:  |
|       Collision Hitbox       | :heavy_check_mark:  |
|      Interaction Hitbox      | :heavy_check_mark:  |
|       Occlusion Hitbox       | :heavy_check_mark:  |
|        Visual Hitbox         | :heavy_check_mark:  |
|        Dynamic Shape         | :heavy_check_mark:  |
|         Solid Render         | :heavy_check_mark:  |
|        Light Emission        | :heavy_check_mark:  |
|         Light Block          | :heavy_check_mark:  |
|   Propagates Skylight Down   | :heavy_check_mark:  |
|  Shape for Light Occlusion   | :heavy_check_mark:  |
|           Opacity            | :heavy_check_mark:  |
|     Conditional Opacity      | :heavy_check_mark:  |
|         Render Shape         | :heavy_check_mark:  |
|            Offset            | :heavy_check_mark:  |
|      Sound Information       | :heavy_check_mark:  |
|    Pick Block Information    | :heavy_check_mark:  |

### Block Entities

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |
|  Block IDs   | :heavy_check_mark:  |

### Block Properties

|    Data Type    |     Supported?      |
|:---------------:|:-------------------:|
|   Mojang Name   | :heavy_check_mark:  |
|       Key       | :heavy_check_mark:  |
| Possible Values | :heavy_check_mark:  |

### Commands

|      Data Type      |     Supported?      |           Description            |
|:-------------------:|:-------------------:|:--------------------------------:|
| Entire Command Tree | :heavy_check_mark:  | See https://wiki.vg/Command_Data |

### Custom Statistics

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |

### Dimension Types

|      Data Type       |     Supported?      |
|:--------------------:|:-------------------:|
|     Namespace ID     | :heavy_check_mark:  |
|      Bed Works       | :heavy_check_mark:  |
|   Coordinate Scale   | :heavy_check_mark:  |
|    Ceiling Height    | :heavy_check_mark:  |
|      Fixed Time      | :heavy_check_mark:  |
|        Raids         | :heavy_check_mark:  |
|      Sky Light       | :heavy_check_mark:  |
|     Piglin Safe      | :heavy_check_mark:  |
|    Logical Height    | :heavy_check_mark:  |
|       Natural        | :heavy_check_mark:  |
|      Ultra Warm      | :heavy_check_mark:  |
| Respawn Anchor Works | :heavy_check_mark:  |
|         MinY         | :heavy_check_mark:  |
|    Height (maxY)     | :heavy_check_mark:  |

### Dye Colors

|            Data Type             |     Supported?      |
|:--------------------------------:|:-------------------:|
|           Protocol ID            | :heavy_check_mark:  |
|           Mojang Name            | :heavy_check_mark:  |
|      Color (Material Color)      | :heavy_check_mark:  |
|     Firework Color (Decimal)     | :heavy_check_mark:  |
|       Text Color (Decimal)       | :heavy_check_mark:  |
|  TextureDiffuseColor (Decimal)   | :heavy_check_mark:  |
| TextureDiffuseColorBGR (Decimal) | :heavy_check_mark:  |
|       TextureDiffuseColors       | :heavy_check_mark:  |

### Enchantments

|         Data Type         |     Supported?      |
|:-------------------------:|:-------------------:|
|        Protocol ID        | :heavy_check_mark:  |
|       Namespace ID        | :heavy_check_mark:  |
|        Mojang Name        | :heavy_check_mark:  |
|      Translation Key      | :heavy_check_mark:  |
|         Max Level         | :heavy_check_mark:  |
|          Rarity           | :heavy_check_mark:  |
|           Curse           | :heavy_check_mark:  |
|       Discoverable        | :heavy_check_mark:  |
|         Tradeable         | :heavy_check_mark:  |
|       Treasure Only       | :heavy_check_mark:  |
|         Category          | :heavy_check_mark:  |
| Incompatible Enchantments | :heavy_check_mark:  |

### Entities

|        Data Type        |     Supported?      |
|:-----------------------:|:-------------------:|
|       Protocol ID       | :heavy_check_mark:  |
|      Namespace ID       | :heavy_check_mark:  |
|       Mojang Name       | :heavy_check_mark:  |
|     Translation Key     | :heavy_check_mark:  |
|     Loot Table Key      | :heavy_check_mark:  |
| Entity Data Packet Info | :heavy_check_mark:  |
|       Packet Type       | :heavy_check_mark:  |
|      Fire Immunity      | :heavy_check_mark:  |
|         Height          | :heavy_check_mark:  |
|          Width          | :heavy_check_mark:  |
|  Client Tracking Range  | :heavy_check_mark:  |

### Entity Data Serializers

|  Data Type  |     Supported?      |
|:-----------:|:-------------------:|
| Protocol ID | :heavy_check_mark:  |
| Mojang Name | :heavy_check_mark:  |

### Fluids

|         Data Type         |     Supported?      |
|:-------------------------:|:-------------------:|
|        Protocol ID        | :heavy_check_mark:  |
|       Namespace ID        | :heavy_check_mark:  |
|        Mojang Name        | :heavy_check_mark:  |
| Corresponding Bucket Item | :heavy_check_mark:  |

### Fluid Properties

| Data Type | Supported? |
|:---------:|:----------:|


### Game Events

|      Data Type      |     Supported?      |
|:-------------------:|:-------------------:|
|     Protocol ID     | :heavy_check_mark:  |
|    Namespace ID     | :heavy_check_mark:  |
|     Mojang Name     | :heavy_check_mark:  |
| Notification Radius | :heavy_check_mark:  |

### Map Colors

|    Data Type    |     Supported?      |
|:---------------:|:-------------------:|
|   Protocol ID   | :heavy_check_mark:  |
|   Mojang Name   | :heavy_check_mark:  |
| Color (Decimal) | :heavy_check_mark:  |

### Items

|        Data Type        |     Supported?      |
|:-----------------------:|:-------------------:|
|       Protocol ID       | :heavy_check_mark:  |
|      Namespace ID       | :heavy_check_mark:  |
|       Mojang Name       | :heavy_check_mark:  |
|     Translation Key     | :heavy_check_mark:  |
|        Depletes         | :heavy_check_mark:  |
|     Max Stack Size      | :heavy_check_mark:  |
| Max Damage (Durability) | :heavy_check_mark:  |
|         Edible          | :heavy_check_mark:  |
|     Fire Resistant      | :heavy_check_mark:  |
|   Corresponding Block   | :heavy_check_mark:  |
| Eating & Drinking Sound | :heavy_check_mark:  |
|     Food Properties     | :heavy_check_mark:  |
|    Armor Properties     | :heavy_check_mark:  |
|  Spawn Egg Properties   | :heavy_check_mark:  |
|     Tool Properties     | :heavy_check_mark:  |
|    Bucket Properties    | :heavy_check_mark:  |
|     Dye Properties      | :heavy_check_mark:  |

### Potion Effects

|    Data Type    |     Supported?      |
|:---------------:|:-------------------:|
|   Protocol ID   | :heavy_check_mark:  |
|  Namespace ID   | :heavy_check_mark:  |
|   Mojang Name   | :heavy_check_mark:  |
| Color (Decimal) | :heavy_check_mark:  |
|  Instanteneous  | :heavy_check_mark:  |

### Packets

|    Data Type     |     Supported?      |
|:----------------:|:-------------------:|
|    Packet ID     | :heavy_check_mark:  |
| Packet Classname | :heavy_check_mark:  |
| Packet Direction | :heavy_check_mark:  |
| Connection State | :heavy_check_mark:  |

### Particles

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |

### Potions

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |

### Recipes

|  Data Type  |     Supported?      |
|:-----------:|:-------------------:|
|  Mojang ID  | :heavy_check_mark:  |
| Recipe Type | :heavy_check_mark:  |
|   Layout    | :heavy_check_mark:  |
|   Recipe    | :heavy_check_mark:  |
|   Result    | :heavy_check_mark:  |

### Sounds

|    Data Type    |     Supported?      |
|:---------------:|:-------------------:|
|   Protocol ID   | :heavy_check_mark:  |
|  Namespace ID   | :heavy_check_mark:  |
|   Mojang Name   | :heavy_check_mark:  |
| Translation Key | :heavy_check_mark:  |

### Sound Sources

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
|     Type     | :heavy_check_mark:  |

### Villager Professions

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |
|  Work Sound  | :heavy_check_mark:  |

### Villager Types

|  Data Type   |     Supported?      |
|:------------:|:-------------------:|
| Protocol ID  | :heavy_check_mark:  |
| Namespace ID | :heavy_check_mark:  |
| Mojang Name  | :heavy_check_mark:  |
